@@ -82,7 +82,7 @@ export PLATFORM_SHORT_ARCH
 export PATH=${ANDROID_NDK}/toolchains/${PATH_HOST}-${GCCVER}/prebuilt/`uname|tr A-Z a-z`-x86/bin:${PATH}
 
 # 1/ libvlc, libvlccore and its plugins
-TESTED_HASH=dfccdf84e19
+TESTED_HASH=9aef14d5e5
 if [ ! -d "vlc" ]; then
     echo "VLC source not found, cloning"
     git clone git://git.videolan.org/vlc.git vlc
@@ -171,7 +171,7 @@ cd contrib/android
 [ ${ANDROID_ABI} = "armeabi-v7a" ] && echo "NOTHUMB := -marm" >> config.mak
 
 # Release or not?
-if [ $# -ne 0 ] && [ "$1" == "release" ]; then
+if [ $# -ne 0 ] && [ "$1" = "release" ]; then
     OPTS=""
     EXTRA_CFLAGS="${EXTRA_CFLAGS} -DNDEBUG "
     RELEASEFLAG="RELEASE=1"
