@@ -599,7 +599,7 @@ public class AudioService extends Service {
     }
 
     private Bitmap getCover() {
-        return AudioUtil.getCover(this, mCurrentMedia, 0);
+        return AudioUtil.getCover(this, mCurrentMedia, 512);
     }
 
     private final IAudioService.Stub mInterface = new IAudioService.Stub() {
@@ -899,7 +899,7 @@ public class AudioService extends Service {
         }
         i.putExtra("isplaying", mLibVLC.isPlaying());
 
-        Bitmap cover = mCurrentMedia != null ? Util.scaleDownBitmap(context, getCover(), 64) : null;
+        Bitmap cover = mCurrentMedia != null ? AudioUtil.getCover(this, mCurrentMedia, 64) : null;
         i.putExtra("cover", cover);
 
         sendBroadcast(i);
