@@ -59,9 +59,9 @@ public class EventManager {
     //public static final int MediaPlayerLengthChanged        = 0x111;
     public static final int MediaPlayerVout                   = 0x112;
 
-    //public static final int MediaListItemAdded              = 0x200;
+    public static final int MediaListItemAdded                = 0x200;
     //public static final int MediaListWillAddItem            = 0x201;
-    //public static final int MediaListItemDeleted            = 0x202;
+    public static final int MediaListItemDeleted              = 0x202;
     //public static final int MediaListWillDeleteItem         = 0x203;
 
     //public static final int MediaListViewItemAdded          = 0x300;
@@ -95,7 +95,7 @@ public class EventManager {
         mEventHandler = new ArrayList<Handler>();
     }
 
-    public static EventManager getIntance() {
+    public static EventManager getInstance() {
         if (mInstance == null) {
             mInstance = new EventManager();
         }
@@ -112,10 +112,8 @@ public class EventManager {
     }
 
     /** This method is called by a native thread **/
-    public void callback(int event, int optional_data) {
-        Bundle b = new Bundle();
+    public void callback(int event, Bundle b) {
         b.putInt("event", event);
-        b.putInt("data", optional_data);
         for (int i = 0; i < mEventHandler.size(); i++) {
             Message msg = Message.obtain();
             msg.setData(b);
