@@ -270,7 +270,24 @@ public class Media implements Comparable<Media> {
     }
 
     public Bitmap getPicture() {
-        return mPicture;
+        // mPicture is not null only if passed through
+        // the ctor which is deprecated by now.
+        if (mPicture == null) {
+            BitmapCache cache = BitmapCache.getInstance();
+            Bitmap picture = cache.getBitmapFromMemCache(mLocation);
+            if (picture == null) {
+                /* Not in memcache:
+                 * serving the file from the database and
+                 * adding it to the memcache for later use.
+                 */
+                Context c = VLCApplication.getAppContext();
+                picture = DatabaseManager.getInstance(c).getPicture(c, mLocation);
+                cache.addBitmapToMemCache(mLocation, picture);
+            }
+            return picture;
+        } else {
+            return mPicture;
+        }
     }
 
     public void setPicture(Context context, Bitmap p) {
@@ -279,7 +296,6 @@ public class Media implements Comparable<Media> {
                 mLocation,
                 DatabaseManager.mediaColumn.MEDIA_PICTURE,
                 p);
-        mPicture = p;
         mIsPictureParsed = true;
     }
 
@@ -296,6 +312,8 @@ public class Media implements Comparable<Media> {
             return mTitle;
         else {
             int end = getFileName().lastIndexOf(".");
+            if (end <= 0)
+                return getFileName();
             return getFileName().substring(0, end);
         }
     }
