@@ -33,7 +33,6 @@ import java.util.HashSet;
 import java.util.Locale;
 import java.util.Properties;
 
-import android.annotation.TargetApi;
 import android.content.Context;
 import android.graphics.Bitmap;
 import android.net.Uri;
@@ -142,6 +141,11 @@ public class Util {
     }
 
     public static Bitmap scaleDownBitmap(Context context, Bitmap bitmap, int width) {
+        /*
+         * This method can lead to OutOfMemoryError!
+         * If the source size is more than twice the target size use
+         * the optimized version available in AudioUtil::readCoverBitmap
+         */
         if (bitmap != null) {
             final float densityMultiplier = context.getResources().getDisplayMetrics().density;
             int w = (int) (width * densityMultiplier);
@@ -240,7 +244,6 @@ public class Util {
         return android.os.Build.VERSION.SDK_INT >= android.os.Build.VERSION_CODES.JELLY_BEAN;
     }
 
-    @TargetApi(9)
     public static boolean hasExternalStorage() {
         return Environment.getExternalStorageState().equals(Environment.MEDIA_MOUNTED);
     }
