@@ -81,7 +81,7 @@ public class AudioUtil {
 
     @SuppressLint("NewApi")
     public static void prepareCacheFolder(Context context) {
-        if (Util.isFroyoOrLater() && Util.hasExternalStorage())
+        if (Util.isFroyoOrLater() && Util.hasExternalStorage() && context.getExternalCacheDir() != null)
             CACHE_DIR = context.getExternalCacheDir().getPath();
         else
             CACHE_DIR = Environment.getExternalStorageDirectory().getPath() + "/Android/data/" + context.getPackageName() + "/cache";
@@ -165,8 +165,13 @@ public class AudioUtil {
         Bitmap cover = null;
         String cachePath = null;
 
+        if (width <= 0) {
+            Log.e(TAG, "Invalid cover width requested");
+            return null;
+        }
+
         // if external storage is not available, skip covers to prevent slow audio browsing
-        if (!Util.hasExternalStorage() && width > 0)
+        if (!Util.hasExternalStorage())
             return null;
 
         try {
@@ -174,8 +179,8 @@ public class AudioUtil {
             int hash = MurmurHash.hash32(media.getArtist()+media.getAlbum());
             cachePath = COVER_DIR + (hash >= 0 ? "" + hash : "m" + (-hash)) + "_" + width;
 
-            BitmapCache cache = BitmapCache.getInstance();
             // try to get the cover from the LRUCache first
+            BitmapCache cache = BitmapCache.getInstance();
             cover = cache.getBitmapFromMemCache(cachePath);
             if (cover != null)
                 return cover;
@@ -189,15 +194,16 @@ public class AudioUtil {
                     return null;
             }
 
-            if (coverPath == null)
+            // try to get it from VLC
+            if (coverPath == null || !cacheFile.exists())
                 coverPath = getCoverFromVlc(context, media);
 
             // no found yet, looking in folder
-            if (coverPath == null)
+            if (coverPath == null || !(new File(coverPath)).exists())
                 coverPath = getCoverFromFolder(context, media);
 
             // try to get the cover from android MediaStore
-            if (coverPath == null)
+            if (coverPath == null || !(new File(coverPath)).exists())
                 coverPath = getCoverFromMediaStore(context, media);
 
             // read (and scale?) the bitmap
@@ -217,6 +223,8 @@ public class AudioUtil {
         OutputStream out = null;
         try {
             File file = new File(path);
+            if (file.exists() && file.length() > 0)
+                return;
             out = new BufferedOutputStream(new FileOutputStream(file), 4096);
             if (bitmap != null)
                 bitmap.compress(CompressFormat.JPEG, 90, out);
@@ -229,12 +237,32 @@ public class AudioUtil {
         }
     }
 
-    private static Bitmap readCoverBitmap(Context context, String path, int width) {
-        Bitmap cover = BitmapFactory.decodeFile(path);
+    private static Bitmap readCoverBitmap(Context context, String path, int dipWidth) {
+        Bitmap cover = null;
+        BitmapFactory.Options options = new BitmapFactory.Options();
+        int width = Util.convertDpToPx(dipWidth);
 
-        // scale down if requested
-        if (cover != null && width > 0)
-            cover = Util.scaleDownBitmap(context, cover, width);
+        /* Get the resolution of the bitmap without allocating the memory */
+        options.inJustDecodeBounds = true;
+        BitmapFactory.decodeFile(path, options);
+
+        if (options.outWidth > 0 && options.outHeight > 0) {
+            options.inJustDecodeBounds = false;
+            options.inSampleSize = 2;
+
+            // Find the best decoding scale for the bitmap
+            while( options.outWidth / options.inSampleSize > width)
+                options.inSampleSize++;
+            options.inSampleSize--;
+
+            // Decode the file (with memory allocation this time)
+            cover = BitmapFactory.decodeFile(path, options);
+
+            if (cover != null && options.outWidth > width) {
+                int height = (int) (width * options.outHeight / ((double) options.outWidth));
+                cover = Bitmap.createScaledBitmap(cover, width, height, false);
+            }
+        }
 
         return cover;
     }
